# Infomap Software Package

Infomap is a network clustering algorithm based on the
[Map equation](http://www.mapequation.org/publications.html#Rosvall-Axelsson-Bergstrom-2009-Map-equation).

For more info, see [www.mapequation.org](http://www.mapequation.org).


Getting started:
--------------------------------------------------------
In a terminal with the GNU Compiler Collection installed,
just run `make` in the current directory to compile the
code with the included `Makefile`. Call `./Infomap` to run.

Run `./Infomap --help` or visit [options](http://www.mapequation.org/code.html#Options)
for a list of available options.

Infomap can be used both as a standalone program and as a library.
See the `examples` folder for examples.

We also include an [IPython notebook](examples/python/infomap-examples.ipynb)
with the examples that can be viewed online.



Authors:
--------------------------------------------------------
Daniel Edler
Martin Rosvall

For contact information, see 
http://www.mapequation.org/about

For a list of recent feature updates, see
CHANGES.txt in the source directory.

Terms of use:
--------------------------------------------------------
The Infomap software is released under a dual licence.

To give everyone maximum freedom to make use of Infomap 
and derivative works, we make the code open source under 
the GNU Affero General Public License version 3 or any 
later version (see LICENSE_AGPLv3.txt.)

For a non-copyleft license, please contact us.
